@@ -3,9 +3,11 @@ pub(crate) use array_or_vec::*;
 
 #[allow(dead_code)]
 mod retry;
-#[cfg(all(target_arch = "x86_64", feature = "into_x86_from_x64"))]
 pub(crate) use retry::*;
 
 #[allow(dead_code)]
 mod uninit_buf;
 pub(crate) use uninit_buf::*;
+
+mod range;
+pub(crate) use range::*;
